==> tora_2.0.0.orig.tar.gz: tora-2.0.0/src/tosearchreplace.h <==

/* BEGIN_COMMON_COPYRIGHT_HEADER
 *
 * TOra - An Oracle Toolkit for DBA's and developers
 * 
 * Shared/mixed copyright is held throughout files in this product
 * 
 * Portions Copyright (C) 2000-2001 Underscore AB
 * Portions Copyright (C) 2003-2005 Quest Software, Inc.
 * Portions Copyright (C) 2004-2008 Numerous Other Contributors
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation;  only version 2 of
 * the License is valid for this program.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 *      As a special exception, you have permission to link this program
 *      with the Oracle Client libraries and distribute executables, as long
 *      as you follow the requirements of the GNU GPL in regard to all of the
 *      software in the executable aside from Oracle client libraries.
 * 
 *      Specifically you are not permitted to link this program with the
 *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
 *      And you are not permitted to distribute binaries compiled against
 *      these libraries. 
 * 
 *      You may link this product with any GPL'd Qt library.
 * 
 * All trademarks belong to their respective owners.
 *
 * END_COMMON_COPYRIGHT_HEADER */

#ifndef TOSEARCHREPLACE_H
#define TOSEARCHREPLACE_H

#include "config.h"
#include "ui_tosearchreplaceui.h"
#include "tohelp.h"
#include "toeditwidget.h"

class toListView;
class toMarkedText;
class toResultContentEditor;

class toSearchReplace : public QDialog, public Ui::toSearchReplaceUI,
            public toHelpContext, public toEditWidget::editHandler
{
    Q_OBJECT

    toEditWidget *Target;
public:
    toSearchReplace(QWidget *parent);
    ~toSearchReplace()
    {
        toEditWidget::delHandler(this);
    }

    virtual void show();
    bool findString(const QString &text, int &pos, int &endPos);
    virtual void receivedFocus(toEditWidget *widget);
    virtual void lostFocus(toEditWidget *)
    {
        receivedFocus(NULL);
    }
    bool searchNextAvailable(void);
public slots:
    virtual void searchNext();
private slots:
    virtual void replaceAll();
    virtual void replace();
    virtual void search();
    virtual void searchChanged();
    virtual void displayHelp();
};

#endif

==> tora_2.1.3.orig.tar.gz: tora-2.1.3/src/tosearchreplace.h <==

/* BEGIN_COMMON_COPYRIGHT_HEADER
 *
 * TOra - An Oracle Toolkit for DBA's and developers
 * 
 * Shared/mixed copyright is held throughout files in this product
 * 
 * Portions Copyright (C) 2000-2001 Underscore AB
 * Portions Copyright (C) 2003-2005 Quest Software, Inc.
 * Portions Copyright (C) 2004-2009 Numerous Other Contributors
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation;  only version 2 of
 * the License is valid for this program.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 *      As a special exception, you have permission to link this program
 *      with the Oracle Client libraries and distribute executables, as long
 *      as you follow the requirements of the GNU GPL in regard to all of the
 *      software in the executable aside from Oracle client libraries.
 * 
 *      Specifically you are not permitted to link this program with the
 *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
 *      And you are not permitted to distribute binaries compiled against
 *      these libraries. 
 * 
 *      You may link this product with any GPL'd Qt library.
 * 
 * All trademarks belong to their respective owners.
 *
 * END_COMMON_COPYRIGHT_HEADER */

#ifndef TOSEARCHREPLACE_H
#define TOSEARCHREPLACE_H

#include "config.h"
#include "ui_tosearchreplaceui.h"
#include "tohelp.h"
#include "toeditwidget.h"

class toListView;
class toMarkedText;
class toResultContentEditor;


//! \brief A helper namespace for Search related tools
namespace Search
{
    enum SearchMode {
        SearchPlaintext = 0,
        SearchRegexp
    };

    enum SearchDirection {
        SearchUndefined = -1,
        SearchForward = 0,
        SearchBackward = 1
    };
}; // namespace Search


class toSearchReplace : public QDialog, public Ui::toSearchReplaceUI,
            public toHelpContext, public toEditWidget::editHandler
{
    Q_OBJECT

    toEditWidget *Target;

public:
    toSearchReplace(QWidget *parent);
    ~toSearchReplace()
    {
        toEditWidget::delHandler(this);
    };

    void show();

    QString currentSearchText();
    Search::SearchMode searchMode();
    bool wholeWords();
    bool caseSensitive();

    virtual void receivedFocus(toEditWidget *widget);
    virtual void lostFocus(toEditWidget *)
    {
        receivedFocus(NULL);
    }

public slots:
    void searchNext();
    void searchPrevious();
private slots:
    void replaceAll();
    void replace();
    void searchChanged(const QString & text);
    void displayHelp();
};

#endif
